# Connect Extension as a Service Core Library

![pyversions](https://img.shields.io/pypi/pyversions/connect-eaas-core.svg) [![PyPi Status](https://img.shields.io/pypi/v/connect-eaas-core.svg)](https://pypi.org/project/connect-eaas-core/) [![Build Status](https://github.com/cloudblue/connect-eaas-core/workflows/Build%20Connect%20EaaS%20Core/badge.svg)](https://github.com/cloudblue/connect-eaas-core/actions) [![Sonarcloud Status](https://sonarcloud.io/api/project_badges/measure?project=connect-eaas-core&metric=alert_status)](https://sonarcloud.io/dashboard?id=connect-eaas-core) 
 [![SonarCloud Coverage](https://sonarcloud.io/api/project_badges/measure?project=connect-eaas-core&metric=coverage)](https://sonarcloud.io/component_measures/metric/coverage/list?id=connect-eaas-core)
 [![SonarCloud Bugs](https://sonarcloud.io/api/project_badges/measure?project=connect-eaas-core&metric=bugs)](https://sonarcloud.io/component_measures/metric/reliability_rating/list?id=connect-eaas-core)
 [![SonarCloud Vulnerabilities](https://sonarcloud.io/api/project_badges/measure?project=connect-eaas-core&metric=vulnerabilities)](https://sonarcloud.io/component_measures/metric/security_rating/list?id=connect-eaas-core)




## Introduction

`Connect EaaS Core` is a library that contains the base building blocks to develop extensions for the CloudBlue Connect platform.


## Install

`Connect EaaS Core` requires python 3.8 or later.


`Connect EaaS Core` can be installed from [pypi.org](https://pypi.org/project/connect-eaas-core/) using pip:

```
$ pip install connect-eaas-core
```


## Documentation

[`Connect EaaS Core` documentation](https://connect-eaas-core.readthedocs.io/en/latest/) is hosted on the _Read the Docs_ service.


## License

`Connect EaaS Core` is released under the [Apache License Version 2.0](https://www.apache.org/licenses/LICENSE-2.0).
